Game

Struct Game 

pub struct Game { /* private fields */ }
The Backgammon Game

This struct holds all the fields necessary to play a single round of Backgammon. The implemented methods for this struct are the ones required to play a single round of Backgammon, e.g. enforcing the right player and other game rules.

Caveat: Even though you can theoretically play one Backgammon game correctly on the Game struct, it is not suggested to operate directly on this struct. To correctly apply all double cube rules, it is recommended to use the Match struct.

//        +12-11-10--9--8--7-------6--5--4--3--2--1-+
//        | X           O    |   | O              X | +-------+
//        | X           O    |   | O              X | | OFF O |
//        | X           O    |   | O                | +-------+
//        | X                |   | O                |
//        | X                |   | O                |
//        |                  |BAR|                  |
//        | O                |   | X                |
//        | O                |   | X                |
//        | O           X    |   | X                | +-------+
//        | O           X    |   | X              O | | OFF X |
//        | O           X    |   | X              O | +-------+
//        +13-14-15-16-17-18------19-20-21-22-23-24-+

Implementations

Source

impl Game

pub fn new() -> Self

Creates a new default game.

pub fn get_state(&self) -> &GameState

Returns the current game state.

pub fn set_player(&mut self, player: Player) -> Result<(), Error>

Sets the current player.

pub fn get_player(&self) -> &Player

Returns the current player. For ended games, returns Nobody.