Implements the board, the dice, the cube, and all other Backgammon rules.
Caveat: Unless you know what you are doing, you should not use this module directly. Only use the Match struct in your implementation.
Modules
- prelude
- Provides commonly used types and structures for ease of use in external modules. It is recommended to always use the prelude module for convenience.
Structs
- Board
- Backgammon Board
- Board
Display - Represents the Backgammon board for graphical representation only.
- Cube
- Represents the Backgammon doubling cube.
- Dice
- Represents the two dice needed to move checkers.
- Rules
- Holds all the rule settings.
Enums
Traits
- Match
Rules - This trait provides methods to modify the rules of a match.
- Move
- Trait to move checkers on the board, respecting all move rules given by classic Backgammon.
- Roll
- Trait to roll the dice.