pub struct Game { /* private fields */ }Expand description
The Backgammon Game
This struct holds all the fields necessary to play a single round of Backgammon. The implemented methods for this struct are the ones required to play a single round of Backgammon, e.g. enforcing the right player and other game rules.
Caveat: Even though you can theoretically play one Backgammon game correctly on the Game struct, it is not suggested to operate directly on this struct. To correctly apply all double cube rules, it is recommended to use the Match struct.
// +12-11-10--9--8--7-------6--5--4--3--2--1-+
// | X O | | O X | +-------+
// | X O | | O X | | OFF O |
// | X O | | O | +-------+
// | X | | O |
// | X | | O |
// | |BAR| |
// | O | | X |
// | O | | X |
// | O X | | X | +-------+
// | O X | | X O | | OFF X |
// | O X | | X O | +-------+
// +13-14-15-16-17-18------19-20-21-22-23-24-+Implementations